Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
Used by the client to invoke a tool provided by the server.
Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
Used by the client to invoke a tool provided by the server.