Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
A request from the server to elicit additional information from the user via the client.
Summary
Functions
Returns the JSON schema for this entity.
Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
A request from the server to elicit additional information from the user via the client.
Returns the JSON schema for this entity.