Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
The contents of a resource, embedded into a prompt or tool call result.
It is up to the client how best to render embedded resources for the benefit of the LLM and/or the user.
Summary
Functions
Returns the JSON schema for this entity.