GenMCP.MCP.V2607.InputRequiredResult (gen_mcp v2.0.0)

Copy Markdown View Source

Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.

An InputRequiredResult sent by the server to indicate that additional input is needed before the request can be completed.

At least one of inputRequests or requestState MUST be present.

Summary

Functions

Returns the JSON schema for this entity.

Types

t()

@type t() :: %GenMCP.MCP.V2607.InputRequiredResult{
  _meta: term(),
  inputRequests: term(),
  requestState: term(),
  resultType: term()
}

Functions

json_schema()

Returns the JSON schema for this entity.