GenMCP.MCP.V2607.ListRootsRequest (gen_mcp v2.0.0)

Copy Markdown View Source

Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.

Sent from the server to request a list of root URIs from the client. Roots allow servers to ask for specific directories or files to operate on. A common example for roots is providing a set of repositories or directories a server should operate on.

This request is typically used when the server needs to understand the file system structure or access specific locations that the client has permission to read from.

Summary

Functions

Returns the JSON schema for this entity.

Types

t()

@type t() :: %GenMCP.MCP.V2607.ListRootsRequest{method: term(), params: term()}

Functions

json_schema()

Returns the JSON schema for this entity.