Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
Describes a message returned as part of a prompt.
This is similar to {@link SamplingMessage}, but also supports the embedding of resources from the MCP server.
Summary
Functions
Returns the JSON schema for this entity.