Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
Sent from the client to the server, to read a specific resource URI.
Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
Sent from the client to the server, to read a specific resource URI.