Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
The result returned by the server for a {@link ReadResourceRequestresources/read} request.
Summary
Functions
Returns the JSON schema for this entity.
Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
The result returned by the server for a {@link ReadResourceRequestresources/read} request.
Returns the JSON schema for this entity.