Struct and module-based JSON schema generated from modelcontextprotocol.io JSON schema.
The set of notification types a client may opt in to on a {@link SubscriptionsListenRequestsubscriptions/listen} request.
Each notification type is opt-in; the server MUST NOT send notification types the client has not explicitly requested here.
Summary
Functions
Returns the JSON schema for this entity.